==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector.md <==
# AmazonBraketStateVector


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')
```



| Illustration | AmazonBraketStateVector | AmazonBraketStateVectorCard | AmazonBraketStateVectorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector.png) | ![illustration for AmazonBraketStateVector](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector.Local.png) | ![illustration for AmazonBraketStateVectorCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVectorCard.Local.png) | ![illustration for AmazonBraketStateVectorGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVectorGroup.Local.png) |




## AmazonBraketStateVector

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVector
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVector('AmazonBraketStateVector', 'Amazon Braket State Vector', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVector
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVector('AmazonBraketStateVector', 'Amazon Braket State Vector', 'an optional tech label')
@enduml
```

## AmazonBraketStateVectorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorCard('AmazonBraketStateVectorCard', 'Amazon Braket State Vector Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorCard('AmazonBraketStateVectorCard', 'Amazon Braket State Vector Card', 'an optional description')
@enduml
```

## AmazonBraketStateVectorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorGroup('AmazonBraketStateVectorGroup', 'Amazon Braket State Vector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorGroup('AmazonBraketStateVectorGroup', 'Amazon Braket State Vector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector.md <==
# AmazonBraketStateVector


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')
```



| Illustration | AmazonBraketStateVector | AmazonBraketStateVectorCard | AmazonBraketStateVectorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector.png) | ![illustration for AmazonBraketStateVector](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector.Local.png) | ![illustration for AmazonBraketStateVectorCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVectorCard.Local.png) | ![illustration for AmazonBraketStateVectorGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVectorGroup.Local.png) |




## AmazonBraketStateVector

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVector
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVector('AmazonBraketStateVector', 'Amazon Braket State Vector', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVector
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVector('AmazonBraketStateVector', 'Amazon Braket State Vector', 'an optional tech label')
@enduml
```

## AmazonBraketStateVectorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorCard('AmazonBraketStateVectorCard', 'Amazon Braket State Vector Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorCard('AmazonBraketStateVectorCard', 'Amazon Braket State Vector Card', 'an optional description')
@enduml
```

## AmazonBraketStateVectorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorGroup('AmazonBraketStateVectorGroup', 'Amazon Braket State Vector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketStateVectorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketStateVector')

' renders the element
AmazonBraketStateVectorGroup('AmazonBraketStateVectorGroup', 'Amazon Braket State Vector Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
